.. _api-utils:

vcs.utils
=========

.. automodule:: vcs.utils

**Public API**

* :ref:`api-utils-annotate`
* :ref:`api-utils-diffs`
* :ref:`api-utils-helpers`

**Private API**

* :ref:`api-utils-lazy`


.. _api-utils-annotate:

Annotate utils
--------------

.. automodule:: vcs.utils.annotate
   :members:


.. _api-utils-diffs:

Diffs utils
-----------

.. automodule:: vcs.utils.diffs
   :members:


.. _api-utils-helpers:

Helpers
-------

.. automodule:: vcs.utils.helpers
   :members:


.. _api-utils-lazy:

Lazy attributes utils
---------------------

.. automodule:: vcs.utils.lazy
   :members:
